@@ -32,7 +32,6 @@
 
 #include <glib/gstdio.h>
 #include "gtkprintoperation-private.h"
-#include "gtkmarshal.h"
 #include "gtkmessagedialog.h"
 
 #include <cairo-pdf.h>
@@ -184,6 +183,10 @@ _gtk_print_operation_platform_backend_launch_preview (GtkPrintOperation *op,
   gchar *preview_cmd;
   GtkSettings *settings;
   GtkPrintSettings *print_settings;
+  GtkPageSetup *page_setup;
+  GKeyFile *key_file = NULL;
+  gchar *data = NULL;
+  gsize data_len;
   gchar *settings_filename = NULL;
   gchar *quoted_filename;
   gchar *quoted_settings_filename;
@@ -205,10 +208,21 @@ _gtk_print_operation_platform_backend_launch_preview (GtkPrintOperation *op,
   if (fd < 0) 
     goto out;
 
+  key_file = g_key_file_new ();
+  
   print_settings = gtk_print_operation_get_print_settings (op);
-  retval = gtk_print_settings_to_file (print_settings, settings_filename, &error);
-  close (fd);
+  gtk_print_settings_to_key_file (print_settings, key_file, NULL);
 
+  page_setup = gtk_print_context_get_page_setup (op->priv->print_context);
+  gtk_page_setup_to_key_file (page_setup, key_file, NULL);
+
+  g_key_file_set_string (key_file, "Print Job", "title", op->priv->job_name);
+
+  data = g_key_file_to_data (key_file, &data_len, &error);
+  if (!data)
+    goto out;
+
+  retval = g_file_set_contents (settings_filename, data, data_len, &error);
   if (!retval)
     goto out;
 
@@ -260,6 +274,12 @@ _gtk_print_operation_platform_backend_launch_preview (GtkPrintOperation *op,
   if (!settings_used)
     g_unlink (settings_filename);
 
+  if (fd > 0)
+    close (fd);
+  
+  if (key_file)
+    g_key_file_free (key_file);
+  g_free (data);
   g_free (settings_filename);
 }
 
@@ -268,9 +288,8 @@ unix_finish_send  (GtkPrintJob *job,
                    gpointer     user_data, 
                    GError      *error)
 {
-  GtkPrintOperationUnix *op_unix;
-
-  op_unix = (GtkPrintOperationUnix *) user_data;
+  GtkPrintOperation *op = (GtkPrintOperation *) user_data;
+  GtkPrintOperationUnix *op_unix = op->priv->platform_data;
 
   if (error != NULL)
     {
@@ -293,6 +312,8 @@ unix_finish_send  (GtkPrintJob *job,
 
   if (op_unix->loop)
     g_main_loop_quit (op_unix->loop);
+
+  g_object_unref (op);
 }
 
 static void
@@ -312,9 +333,12 @@ unix_end_run (GtkPrintOperation *op,
   
   /* TODO: Check for error */
   if (op_unix->job != NULL)
-    gtk_print_job_send (op_unix->job,
-                        unix_finish_send, 
-                        op_unix, NULL);
+    {
+      g_object_ref (op);
+      gtk_print_job_send (op_unix->job,
+                          unix_finish_send, 
+                          op, NULL);
+    }
 
   if (wait)
     {
@@ -339,13 +363,32 @@ job_status_changed_cb (GtkPrintJob       *job,
 }
 
 
+static void
+printer_changed_cb (GtkPrintUnixDialog *print_dialog, 
+                    GParamSpec         *pspec,
+                    gpointer            user_data)
+{
+  GtkPageSetup             *page_setup;
+  GtkPrintSettings         *print_settings;
+  GtkPrintOperation        *op = user_data;
+  GtkPrintOperationPrivate *priv = op->priv;
+
+  page_setup = gtk_print_unix_dialog_get_page_setup (print_dialog);
+  print_settings = gtk_print_unix_dialog_get_settings (print_dialog);
+
+  g_signal_emit_by_name (op,
+                         "update-custom-widget",
+                         priv->custom_widget,
+                         page_setup,
+                         print_settings);
+}
+
 static GtkWidget *
 get_print_dialog (GtkPrintOperation *op,
                   GtkWindow         *parent)
 {
   GtkPrintOperationPrivate *priv = op->priv;
   GtkWidget *pd, *label;
-  GtkPageSetup *page_setup;
   const gchar *custom_tab_label;
 
   pd = gtk_print_unix_dialog_new (NULL, parent);
@@ -362,13 +405,11 @@ get_print_dialog (GtkPrintOperation *op,
     gtk_print_unix_dialog_set_settings (GTK_PRINT_UNIX_DIALOG (pd),
 					priv->print_settings);
   if (priv->default_page_setup)
-    page_setup = gtk_page_setup_copy (priv->default_page_setup);
-  else
-    page_setup = gtk_page_setup_new ();
+    gtk_print_unix_dialog_set_page_setup (GTK_PRINT_UNIX_DIALOG (pd), 
+                                          priv->default_page_setup);
 
-  gtk_print_unix_dialog_set_page_setup (GTK_PRINT_UNIX_DIALOG (pd), 
-                                        page_setup);
-  g_object_unref (page_setup);
+  gtk_print_unix_dialog_set_current_page (GTK_PRINT_UNIX_DIALOG (pd), 
+                                          priv->current_page);
 
   g_signal_emit_by_name (op, "create-custom-widget",
 			 &priv->custom_widget);
@@ -388,6 +429,8 @@ get_print_dialog (GtkPrintOperation *op,
       
       gtk_print_unix_dialog_add_custom_tab (GTK_PRINT_UNIX_DIALOG (pd),
 					    priv->custom_widget, label);
+
+      g_signal_connect (pd, "notify::selected-printer", (GCallback) printer_changed_cb, op);
     }
   
   return pd;
@@ -428,6 +471,10 @@ finish_print (PrintResponseData *rdata,
     {
       gtk_print_operation_set_print_settings (op, settings);
       priv->print_context = _gtk_print_context_new (op);
+
+      if ( (page_setup != NULL) && (gtk_print_operation_get_default_page_setup (op) == NULL))
+        gtk_print_operation_set_default_page_setup (op, page_setup);
+
       _gtk_print_context_set_page_setup (priv->print_context, page_setup);
 
       if (!rdata->do_preview)
@@ -666,6 +713,13 @@ _gtk_print_operation_platform_backend_create_preview_surface (GtkPrintOperation
   
   filename = g_build_filename (g_get_tmp_dir (), "previewXXXXXX.pdf", NULL);
   fd = g_mkstemp (filename);
+
+  if (fd < 0)
+    {
+      g_free (filename);
+      return NULL;
+    }
+
   *target = filename;
   
   paper_size = gtk_page_setup_get_paper_size (page_setup);
@@ -673,7 +727,7 @@ _gtk_print_operation_platform_backend_create_preview_surface (GtkPrintOperation
   h = gtk_paper_size_get_height (paper_size, GTK_UNIT_POINTS);
     
   *dpi_x = *dpi_y = 72;
-  surface = cairo_pdf_surface_create_for_stream (write_preview, GINT_TO_POINTER(fd), w, h);
+  surface = cairo_pdf_surface_create_for_stream (write_preview, GINT_TO_POINTER (fd), w, h);
  
   cairo_surface_set_user_data (surface, &key, GINT_TO_POINTER (fd), close_preview);
 
